multidim.PointCloud.dists — GDA Toolbox v1.0 Manual

# multidim.PointCloud.dists

`PointCloud.` `dists`(indices0, indices1)

  Compute distances points indices0 and indices1. indices0 and indices1 must be 1-dimensional np arrays, so use not “5” but “np.array([5])”

  The return is a np array with shape == (len(indices0), len(indices1))

  This uses the distance cache, depending on self.cache_type. You can query the size of the cache with `cache_usage()`.

#### Previous topic

multidim.PointCloud.cover_ball

#### Next topic

multidim.PointCloud.from_distances